@@ -2,13 +2,13 @@ package Data::Conveyor::App::Test::Stage;
 
 use strict;
 use warnings;
-use YAML::Active qw/Dump Reload/;
+use YAML::Active 'Dump';
 use String::FlexMatch::Test;
 use Test::More;
 use Data::Dumper;
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
 
 use base 'Class::Scaffold::App::Test::YAMLDriven';
@@ -40,7 +40,11 @@ sub execute_test_def {
     } else {
         $self->make_ticket($testname);
         $self->SUPER::execute_test_def($testname);
-        $self->ticket->delete;
+
+        # During the test run it's not really necessary to delete the ticket
+        # because we'll rollback anyway, and deleting a ticket is expensive.
+
+        # $self->ticket->delete;
     }
 }
 
@@ -48,9 +52,12 @@ sub execute_test_def {
 sub make_ticket {
     my ($self, $testname) = @_;
 
-    $self->test_def($testname,
-        Reload($self->test_def($testname), $self->delegate->YAP_MAKE_TICKET)
-    );
+    # No support for phases at this time - we don't need them and Reload() is
+    # expensive.
+
+    # $self->test_def($testname,
+    #     Reload($self->test_def($testname), $self->delegate->YAP_MAKE_TICKET)
+    # );
 
     my $ticket = $self->delegate->make_obj('test_ticket')->make_whole_ticket(
         %{$self->test_def($testname)->{make_whole_ticket}}
@@ -146,11 +153,8 @@ sub run_test {
 }
 
 
-sub test_expectations {
-    my $self = shift;
-    # give the objects a chance to prepare themselves for comparison
-    $self->ticket->comparable;
-}
+# so subclasses can call SUPER::
+sub test_expectations {}
 
 
 sub plan_ticket_expected_container {
@@ -519,7 +523,8 @@ functions:
 The superclass L<Class::Scaffold::Base> defines these methods and
 functions:
 
-    new(), add_autoloaded_package(), init(), log()
+    new(), FIRST_CONSTRUCTOR_ARGS(), add_autoloaded_package(), init(),
+    log()
 
 The superclass L<Data::Inherited> defines these methods and functions:
 
@@ -638,21 +643,11 @@ The superclass L<Tie::StdHash> defines these methods and functions:
     CLEAR(), DELETE(), EXISTS(), FETCH(), FIRSTKEY(), NEXTKEY(), SCALAR(),
     TIEHASH()
 
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<dataconveyor> tag.
-
-=head1 VERSION 
-                   
-This document describes version 0.03 of L<Data::Conveyor::App::Test::Stage>.
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-data-conveyor@rt.cpan.org>>, or through the web interface at
+Please report any bugs or feature requests through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -667,8 +662,6 @@ site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
 =head1 AUTHORS
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
-
 Florian Helmberger C<< <fh@univie.ac.at> >>
 
 Achim Adam C<< <ac@univie.ac.at> >>
@@ -677,9 +670,11 @@ Mark Hofstetter C<< <mh@univie.ac.at> >>
 
 Heinz Ekker C<< <ek@univie.ac.at> >>
 
+Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 by Marcel GrE<uuml>nauer
+Copyright 2004-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
