@@ -8,7 +8,7 @@ use Test::More;
 use Test::Builder;
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
 
 use base 'Data::Conveyor::App::Test::Stage';
@@ -447,10 +447,11 @@ methods and functions:
     current_test_def(), current_test_def_clear(), delete_test_def(),
     exists_test_def(), expect(), expect_clear(), keys_test_def(),
     make_plan(), named_test(), read_test_defs(), run_num(),
-    run_num_clear(), runs_clear(), should_skip(), should_skip_testname(),
-    test_def(), test_def_clear(), test_def_delete(), test_def_exists(),
-    test_def_keys(), test_def_values(), testdir(), testdir_clear(),
-    testname(), testname_clear(), todo_skip_test(), values_test_def()
+    run_num_clear(), runs(), runs_clear(), should_skip(),
+    should_skip_testname(), test_def(), test_def_clear(),
+    test_def_delete(), test_def_exists(), test_def_keys(),
+    test_def_values(), testdir(), testdir_clear(), testname(),
+    testname_clear(), todo_skip_test(), values_test_def()
 
 The superclass L<Class::Scaffold::App::CommandLine> defines these methods
 and functions:
@@ -477,7 +478,8 @@ functions:
 The superclass L<Class::Scaffold::Base> defines these methods and
 functions:
 
-    new(), add_autoloaded_package(), init(), log()
+    new(), FIRST_CONSTRUCTOR_ARGS(), add_autoloaded_package(), init(),
+    log()
 
 The superclass L<Data::Inherited> defines these methods and functions:
 
@@ -596,21 +598,11 @@ The superclass L<Tie::StdHash> defines these methods and functions:
     CLEAR(), DELETE(), EXISTS(), FETCH(), FIRSTKEY(), NEXTKEY(), SCALAR(),
     TIEHASH()
 
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<dataconveyor> tag.
-
-=head1 VERSION 
-                   
-This document describes version 0.03 of L<Data::Conveyor::App::Test::Stage::Integration>.
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-data-conveyor@rt.cpan.org>>, or through the web interface at
+Please report any bugs or feature requests through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -625,8 +617,6 @@ site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
 =head1 AUTHORS
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
-
 Florian Helmberger C<< <fh@univie.ac.at> >>
 
 Achim Adam C<< <ac@univie.ac.at> >>
@@ -635,9 +625,11 @@ Mark Hofstetter C<< <mh@univie.ac.at> >>
 
 Heinz Ekker C<< <ek@univie.ac.at> >>
 
+Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 by Marcel GrE<uuml>nauer
+Copyright 2004-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
