@@ -6,7 +6,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
 
 use base 'Data::Conveyor::Ticket::Payload::Item';
@@ -52,11 +52,11 @@ L<Data::Conveyor::Ticket::Payload::Item>.
 The superclass L<Data::Conveyor::Ticket::Payload::Item> defines these
 methods and functions:
 
-    apply_instruction_container(), check(), clear_implicit(), data(),
-    exception_container(), exception_container_clear(),
-    exception_container_exists(), has_problematic_exceptions(), implicit(),
-    implicit_clear(), implicit_set(), prepare_comparable(), rc(),
-    set_implicit(), status()
+    DATA_PROPERTY(), apply_instruction_container(), check(),
+    clear_implicit(), data(), exception_container(),
+    exception_container_clear(), exception_container_exists(),
+    has_problematic_exceptions(), implicit(), implicit_clear(),
+    implicit_set(), prepare_comparable(), rc(), set_implicit(), status()
 
 The superclass L<Class::Scaffold::Storable> defines these methods and
 functions:
@@ -71,7 +71,8 @@ functions:
 The superclass L<Class::Scaffold::Base> defines these methods and
 functions:
 
-    new(), add_autoloaded_package(), init(), log()
+    new(), FIRST_CONSTRUCTOR_ARGS(), add_autoloaded_package(), init(),
+    log()
 
 The superclass L<Data::Inherited> defines these methods and functions:
 
@@ -190,21 +191,11 @@ The superclass L<Tie::StdHash> defines these methods and functions:
     CLEAR(), DELETE(), EXISTS(), FETCH(), FIRSTKEY(), NEXTKEY(), SCALAR(),
     TIEHASH()
 
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<dataconveyor> tag.
-
-=head1 VERSION 
-                   
-This document describes version 0.03 of L<Data::Conveyor::Ticket::Payload::Lock>.
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-data-conveyor@rt.cpan.org>>, or through the web interface at
+Please report any bugs or feature requests through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -219,8 +210,6 @@ site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
 =head1 AUTHORS
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
-
 Florian Helmberger C<< <fh@univie.ac.at> >>
 
 Achim Adam C<< <ac@univie.ac.at> >>
@@ -229,9 +218,11 @@ Mark Hofstetter C<< <mh@univie.ac.at> >>
 
 Heinz Ekker C<< <ek@univie.ac.at> >>
 
+Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 by Marcel GrE<uuml>nauer
+Copyright 2004-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
