@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
 
 use base 'Data::Conveyor::Value::Enum';
@@ -139,7 +139,7 @@ functions:
 The superclass L<Class::Scaffold::Base> defines these methods and
 functions:
 
-    add_autoloaded_package()
+    FIRST_CONSTRUCTOR_ARGS(), add_autoloaded_package()
 
 The superclass L<Data::Comparable> defines these methods and functions:
 
@@ -205,21 +205,11 @@ The superclass L<Class::Factory> defines these methods and functions:
     get_registered_classes(), get_registered_types(),
     remove_factory_type(), unregister_factory_type()
 
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<dataconveyor> tag.
-
-=head1 VERSION 
-                   
-This document describes version 0.03 of L<Data::Conveyor::Value::Command>.
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-data-conveyor@rt.cpan.org>>, or through the web interface at
+Please report any bugs or feature requests through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -234,8 +224,6 @@ site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
 =head1 AUTHORS
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
-
 Florian Helmberger C<< <fh@univie.ac.at> >>
 
 Achim Adam C<< <ac@univie.ac.at> >>
@@ -244,9 +232,11 @@ Mark Hofstetter C<< <mh@univie.ac.at> >>
 
 Heinz Ekker C<< <ek@univie.ac.at> >>
 
+Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 by Marcel GrE<uuml>nauer
+Copyright 2004-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
